@@ -9,9 +9,11 @@ import json
 import time
 import re
 import copy
+import uuid
 
 from knack.log import get_logger
 from knack.util import CLIError
+from ._constants import HttpHeaders
 import azure.cli.core.azclierror as CLIErrors
 
 from azure.appconfiguration import (ConfigurationSetting,
@@ -84,6 +86,10 @@ def set_feature(cmd,
     retry_interval = 1
 
     label = label if label and label != SearchFilterOptions.EMPTY_LABEL else None
+
+    # generate correlation request id for operations in the same activity
+    correlation_request_id = str(uuid.uuid4())
+
     for i in range(0, retry_times):
         retrieved_kv = None
         set_kv = None
@@ -91,7 +97,7 @@ def set_feature(cmd,
         new_kv = None
 
         try:
-            retrieved_kv = azconfig_client.get_configuration_setting(key=key, label=label)
+            retrieved_kv = azconfig_client.get_configuration_setting(key=key, label=label, headers={HttpHeaders.CORRELATION_REQUEST_ID: correlation_request_id})
         except ResourceNotFoundError:
             logger.debug("Feature flag '%s' with label '%s' not found. A new feature flag will be created.", feature, label)
         except HttpResponseError as exception:
@@ -145,9 +151,9 @@ def set_feature(cmd,
 
         try:
             if set_configsetting.etag is None:
-                new_kv = azconfig_client.add_configuration_setting(set_configsetting)
+                new_kv = azconfig_client.add_configuration_setting(set_configsetting, headers={HttpHeaders.CORRELATION_REQUEST_ID: correlation_request_id})
             else:
-                new_kv = azconfig_client.set_configuration_setting(set_configsetting, match_condition=MatchConditions.IfNotModified)
+                new_kv = azconfig_client.set_configuration_setting(set_configsetting, match_condition=MatchConditions.IfNotModified, headers={HttpHeaders.CORRELATION_REQUEST_ID: correlation_request_id})
             return map_keyvalue_to_featureflag(convert_configurationsetting_to_keyvalue(new_kv))
 
         except ResourceReadOnlyError:
@@ -184,9 +190,13 @@ def delete_feature(cmd,
 
     azconfig_client = get_appconfig_data_client(cmd, name, connection_string, auth_mode, endpoint)
 
+    # generate correlation request id for operations in the same activity
+    correlation_request_id = str(uuid.uuid4())
+
     retrieved_keyvalues = __list_all_keyvalues(azconfig_client,
                                                key_filter=key_filter,
-                                               label=SearchFilterOptions.EMPTY_LABEL if label is None else label)
+                                               label=SearchFilterOptions.EMPTY_LABEL if label is None else label,
+                                               correlation_request_id=correlation_request_id)
 
     confirmation_message = "Found '{}' feature flags matching the specified feature and label. Are you sure you want to delete these feature flags?".format(len(retrieved_keyvalues))
     user_confirmation(confirmation_message, yes)
@@ -199,7 +209,8 @@ def delete_feature(cmd,
             deleted_kv = azconfig_client.delete_configuration_setting(key=entry.key,
                                                                       label=entry.label,
                                                                       etag=entry.etag,
-                                                                      match_condition=MatchConditions.IfNotModified)
+                                                                      match_condition=MatchConditions.IfNotModified,
+                                                                      headers={HttpHeaders.CORRELATION_REQUEST_ID: correlation_request_id})
             deleted_kvs.append(convert_configurationsetting_to_keyvalue(deleted_kv))
         except ResourceReadOnlyError:
             exception = "Failed to delete read-only feature '{}' with label '{}'. Unlock the feature flag before deleting it.".format(feature_name, entry.label)
@@ -286,64 +297,19 @@ def list_feature(cmd,
                  all_=False,
                  auth_mode="key",
                  endpoint=None):
-    if key and feature:
-        logger.warning("Since both `--key` and `--feature` are provided, `--feature` argument will be ignored.")
-
-    if key is not None:
-        key_filter = key
-    elif feature is not None:
-        key_filter = FeatureFlagConstants.FEATURE_FLAG_PREFIX + feature
-    else:
-        key_filter = FeatureFlagConstants.FEATURE_FLAG_PREFIX + SearchFilterOptions.ANY_KEY
-
-    azconfig_client = get_appconfig_data_client(cmd, name, connection_string, auth_mode, endpoint)
-    try:
-        retrieved_keyvalues = __list_all_keyvalues(azconfig_client,
-                                                   key_filter=key_filter,
-                                                   label=label if label else SearchFilterOptions.ANY_LABEL)
-        retrieved_featureflags = []
-
-        invalid_ffs = 0
-        for kv in retrieved_keyvalues:
-            try:
-                retrieved_featureflags.append(
-                    map_keyvalue_to_featureflag(
-                        keyvalue=kv, show_conditions=True))
-            except (ValueError) as exception:
-                logger.warning("%s\n", exception)
-                invalid_ffs += 1
-                continue
-
-        if invalid_ffs > 0:
-            logger.warning("Found %s invalid feature flags. These feature flags will be skipped.", invalid_ffs)
-
-        filtered_featureflags = []
-        count = 0
-
-        if all_:
-            top = len(retrieved_featureflags)
-        elif top is None:
-            top = 100
-
-        for featureflag in retrieved_featureflags:
-            if fields:
-                partial_featureflags = {}
-                for field in fields:
-                    # featureflag is guaranteed to have all the fields because
-                    # we validate this in map_keyvalue_to_featureflag()
-                    # So this line will never throw AttributeError
-                    partial_featureflags[field.name.lower()] = getattr(
-                        featureflag, field.name.lower())
-                filtered_featureflags.append(partial_featureflags)
-            else:
-                filtered_featureflags.append(featureflag)
-            count += 1
-            if count >= top:
-                break
-        return filtered_featureflags
-
-    except Exception as exception:
-        raise CLIError(str(exception))
+    return __list_features(
+        cmd=cmd,
+        feature=feature,
+        key=key,
+        name=name,
+        label=label,
+        fields=fields,
+        connection_string=connection_string,
+        top=top,
+        all_=all_,
+        auth_mode=auth_mode,
+        endpoint=endpoint
+    )
 
 
 def lock_feature(cmd,
@@ -366,11 +332,14 @@ def lock_feature(cmd,
 
     azconfig_client = get_appconfig_data_client(cmd, name, connection_string, auth_mode, endpoint)
 
+    # generate correlation request id for operations in the same activity
+    correlation_request_id = str(uuid.uuid4())
+
     retry_times = 3
     retry_interval = 1
     for i in range(0, retry_times):
         try:
-            retrieved_kv = azconfig_client.get_configuration_setting(key=key, label=label)
+            retrieved_kv = azconfig_client.get_configuration_setting(key=key, label=label, headers={HttpHeaders.CORRELATION_REQUEST_ID: correlation_request_id})
         except ResourceNotFoundError:
             raise CLIErrors.ResourceNotFoundError("Feature '{}' with label '{}' does not exist.".format(feature, label))
         except HttpResponseError as exception:
@@ -383,7 +352,7 @@ def lock_feature(cmd,
         user_confirmation(confirmation_message, yes)
 
         try:
-            new_kv = azconfig_client.set_read_only(retrieved_kv, match_condition=MatchConditions.IfNotModified)
+            new_kv = azconfig_client.set_read_only(retrieved_kv, match_condition=MatchConditions.IfNotModified, headers={HttpHeaders.CORRELATION_REQUEST_ID: correlation_request_id})
             return map_keyvalue_to_featureflag(convert_configurationsetting_to_keyvalue(new_kv),
                                                show_conditions=False)
         except HttpResponseError as exception:
@@ -417,11 +386,14 @@ def unlock_feature(cmd,
 
     azconfig_client = get_appconfig_data_client(cmd, name, connection_string, auth_mode, endpoint)
 
+    # generate correlation request id for operations in the same activity
+    correlation_request_id = str(uuid.uuid4())
+
     retry_times = 3
     retry_interval = 1
     for i in range(0, retry_times):
         try:
-            retrieved_kv = azconfig_client.get_configuration_setting(key=key, label=label)
+            retrieved_kv = azconfig_client.get_configuration_setting(key=key, label=label, headers={HttpHeaders.CORRELATION_REQUEST_ID: correlation_request_id})
         except ResourceNotFoundError:
             raise CLIErrors.ResourceNotFoundError("Feature '{}' with label '{}' does not exist.".format(feature, label))
         except HttpResponseError as exception:
@@ -434,7 +406,7 @@ def unlock_feature(cmd,
         user_confirmation(confirmation_message, yes)
 
         try:
-            new_kv = azconfig_client.set_read_only(retrieved_kv, read_only=False, match_condition=MatchConditions.IfNotModified)
+            new_kv = azconfig_client.set_read_only(retrieved_kv, read_only=False, match_condition=MatchConditions.IfNotModified, headers={HttpHeaders.CORRELATION_REQUEST_ID: correlation_request_id})
             return map_keyvalue_to_featureflag(convert_configurationsetting_to_keyvalue(new_kv),
                                                show_conditions=False)
         except HttpResponseError as exception:
@@ -468,11 +440,14 @@ def enable_feature(cmd,
 
     azconfig_client = get_appconfig_data_client(cmd, name, connection_string, auth_mode, endpoint)
 
+    # generate correlation request id for operations in the same activity
+    correlation_request_id = str(uuid.uuid4())
+
     retry_times = 3
     retry_interval = 1
     for i in range(0, retry_times):
         try:
-            retrieved_kv = azconfig_client.get_configuration_setting(key=key, label=label)
+            retrieved_kv = azconfig_client.get_configuration_setting(key=key, label=label, headers={HttpHeaders.CORRELATION_REQUEST_ID: correlation_request_id})
         except ResourceNotFoundError:
             raise CLIErrors.ResourceNotFoundError("Feature flag '{}' with label '{}' not found.".format(feature, label))
         except HttpResponseError as exception:
@@ -495,7 +470,8 @@ def enable_feature(cmd,
                                                             retrieved_kv=retrieved_kv,
                                                             updated_value=json.dumps(feature_flag_value,
                                                                                      default=lambda o: o.__dict__,
-                                                                                     ensure_ascii=False))
+                                                                                     ensure_ascii=False),
+                                                            correlation_request_id=correlation_request_id)
 
             return map_keyvalue_to_featureflag(keyvalue=updated_key_value, show_conditions=False)
 
@@ -530,11 +506,14 @@ def disable_feature(cmd,
 
     azconfig_client = get_appconfig_data_client(cmd, name, connection_string, auth_mode, endpoint)
 
+    # generate correlation request id for operations in the same activity
+    correlation_request_id = str(uuid.uuid4())
+
     retry_times = 3
     retry_interval = 1
     for i in range(0, retry_times):
         try:
-            retrieved_kv = azconfig_client.get_configuration_setting(key=key, label=label)
+            retrieved_kv = azconfig_client.get_configuration_setting(key=key, label=label, headers={HttpHeaders.CORRELATION_REQUEST_ID: correlation_request_id})
         except ResourceNotFoundError:
             raise CLIErrors.ResourceNotFoundError("Feature flag '{}' with label '{}' not found.".format(feature, label))
         except HttpResponseError as exception:
@@ -557,7 +536,8 @@ def disable_feature(cmd,
                                                             retrieved_kv=retrieved_kv,
                                                             updated_value=json.dumps(feature_flag_value,
                                                                                      default=lambda o: o.__dict__,
-                                                                                     ensure_ascii=False))
+                                                                                     ensure_ascii=False),
+                                                            correlation_request_id=correlation_request_id)
 
             return map_keyvalue_to_featureflag(keyvalue=updated_key_value, show_conditions=False)
 
@@ -606,11 +586,14 @@ def add_filter(cmd,
         filter_parameters = {}
     new_filter = FeatureFilter(filter_name, filter_parameters)
 
+    # generate correlation request id for operations in the same activity
+    correlation_request_id = str(uuid.uuid4())
+
     retry_times = 3
     retry_interval = 1
     for i in range(0, retry_times):
         try:
-            retrieved_kv = azconfig_client.get_configuration_setting(key=key, label=label)
+            retrieved_kv = azconfig_client.get_configuration_setting(key=key, label=label, headers={HttpHeaders.CORRELATION_REQUEST_ID: correlation_request_id})
         except ResourceNotFoundError:
             raise CLIErrors.ResourceNotFoundError("Feature flag '{}' with label '{}' not found.".format(feature, label))
         except HttpResponseError as exception:
@@ -646,7 +629,8 @@ def add_filter(cmd,
                                         retrieved_kv=retrieved_kv,
                                         updated_value=json.dumps(feature_flag_value,
                                                                  default=lambda o: o.__dict__,
-                                                                 ensure_ascii=False))
+                                                                 ensure_ascii=False),
+                                        correlation_request_id=correlation_request_id)
 
             return new_filter
 
@@ -698,12 +682,16 @@ def update_filter(cmd,
         filter_parameters = {}
     new_filter = FeatureFilter(filter_name, filter_parameters)
 
+    # generate correlation request id for operations in the same activity
+    correlation_request_id = str(uuid.uuid4())
+
     retry_times = 3
     retry_interval = 1
     for i in range(0, retry_times):
         try:
             retrieved_kv = azconfig_client.get_configuration_setting(
-                key=key, label=label)
+                key=key, label=label,
+                headers={HttpHeaders.CORRELATION_REQUEST_ID: correlation_request_id})
         except ResourceNotFoundError:
             raise CLIErrors.ResourceNotFoundError(
                 "Feature flag '{}' with label '{}' not found.".format(feature, label))
@@ -777,7 +765,8 @@ def update_filter(cmd,
                                         retrieved_kv=retrieved_kv,
                                         updated_value=json.dumps(feature_flag_value,
                                                                  default=lambda o: o.__dict__,
-                                                                 ensure_ascii=False))
+                                                                 ensure_ascii=False),
+                                        correlation_request_id=correlation_request_id)
 
             return new_filter
 
@@ -815,6 +804,9 @@ def delete_filter(cmd,
     # Get feature name from key for logging. If users have provided a different feature name, we ignore it anyway.
     feature = key[len(FeatureFlagConstants.FEATURE_FLAG_PREFIX):]
 
+    # generate correlation request id for operations in the same activity
+    correlation_request_id = str(uuid.uuid4())
+
     azconfig_client = get_appconfig_data_client(cmd, name, connection_string, auth_mode, endpoint)
 
     if index is None:
@@ -830,7 +822,7 @@ def delete_filter(cmd,
     retry_interval = 1
     for i in range(0, retry_times):
         try:
-            retrieved_kv = azconfig_client.get_configuration_setting(key=key, label=label)
+            retrieved_kv = azconfig_client.get_configuration_setting(key=key, label=label, headers={HttpHeaders.CORRELATION_REQUEST_ID: correlation_request_id})
         except ResourceNotFoundError:
             raise CLIErrors.ResourceNotFoundError("Feature flag '{}' with label '{}' not found.".format(feature, label))
         except HttpResponseError as exception:
@@ -896,7 +888,8 @@ def delete_filter(cmd,
                                         retrieved_kv=retrieved_kv,
                                         updated_value=json.dumps(feature_flag_value,
                                                                  default=lambda o: o.__dict__,
-                                                                 ensure_ascii=False))
+                                                                 ensure_ascii=False),
+                                        correlation_request_id=correlation_request_id)
 
             return display_filter
 
@@ -1033,26 +1026,123 @@ def list_filter(cmd,
 # Helper functions #
 
 
-def __clear_filter(azconfig_client,
-                   feature,
-                   label=None,
-                   yes=False):
+def __list_features(
+    cmd,
+    feature=None,
+    key=None,
+    name=None,
+    label=None,
+    fields=None,
+    connection_string=None,
+    top=None,
+    all_=False,
+    auth_mode="key",
+    endpoint=None,
+    correlation_request_id=None,
+):
+    if key and feature:
+        logger.warning(
+            "Since both `--key` and `--feature` are provided, `--feature` argument will be ignored."
+        )
+
+    if key is not None:
+        key_filter = key
+    elif feature is not None:
+        key_filter = FeatureFlagConstants.FEATURE_FLAG_PREFIX + feature
+    else:
+        key_filter = (
+            FeatureFlagConstants.FEATURE_FLAG_PREFIX + SearchFilterOptions.ANY_KEY
+        )
+
+    azconfig_client = get_appconfig_data_client(
+        cmd, name, connection_string, auth_mode, endpoint
+    )
+    try:
+        retrieved_keyvalues = __list_all_keyvalues(
+            azconfig_client,
+            key_filter=key_filter,
+            label=label if label else SearchFilterOptions.ANY_LABEL,
+            correlation_request_id=correlation_request_id,
+        )
+        retrieved_featureflags = []
+
+        invalid_ffs = 0
+        for kv in retrieved_keyvalues:
+            try:
+                retrieved_featureflags.append(
+                    map_keyvalue_to_featureflag(keyvalue=kv, show_conditions=True)
+                )
+            except ValueError as exception:
+                logger.warning("%s\n", exception)
+                invalid_ffs += 1
+                continue
+
+        if invalid_ffs > 0:
+            logger.warning(
+                "Found %s invalid feature flags. These feature flags will be skipped.",
+                invalid_ffs,
+            )
+
+        filtered_featureflags = []
+        count = 0
+
+        if all_:
+            top = len(retrieved_featureflags)
+        elif top is None:
+            top = 100
+
+        for featureflag in retrieved_featureflags:
+            if fields:
+                partial_featureflags = {}
+                for field in fields:
+                    # featureflag is guaranteed to have all the fields because
+                    # we validate this in map_keyvalue_to_featureflag()
+                    # So this line will never throw AttributeError
+                    partial_featureflags[field.name.lower()] = getattr(
+                        featureflag, field.name.lower()
+                    )
+                filtered_featureflags.append(partial_featureflags)
+            else:
+                filtered_featureflags.append(featureflag)
+            count += 1
+            if count >= top:
+                break
+        return filtered_featureflags
+
+    except Exception as exception:
+        raise CLIError(str(exception))
+
+
+def __clear_filter(azconfig_client, feature, label=None, yes=False):
     key = FeatureFlagConstants.FEATURE_FLAG_PREFIX + feature
 
+    # generate correlation request id for operations in the same activity
+    correlation_request_id = str(uuid.uuid4())
+
     retry_times = 3
     retry_interval = 1
     for i in range(0, retry_times):
         try:
-            retrieved_kv = azconfig_client.get_configuration_setting(key=key, label=label)
+            retrieved_kv = azconfig_client.get_configuration_setting(
+                key=key, label=label,
+                headers={HttpHeaders.CORRELATION_REQUEST_ID: correlation_request_id}
+            )
         except ResourceNotFoundError:
-            raise CLIErrors.ResourceNotFoundError("Feature flag '{}' with label '{}' not found.".format(feature, label))
+            raise CLIErrors.ResourceNotFoundError(
+                "Feature flag '{}' with label '{}' not found.".format(feature, label)
+            )
         except HttpResponseError as exception:
-            raise CLIErrors.AzureResponseError("Failed to retrieve feature flags from config store. " + str(exception))
+            raise CLIErrors.AzureResponseError(
+                "Failed to retrieve feature flags from config store. " + str(exception)
+            )
 
         try:
-            if retrieved_kv is None or retrieved_kv.content_type != FeatureFlagConstants.FEATURE_FLAG_CONTENT_TYPE:
+            if (
+                retrieved_kv is None or retrieved_kv.content_type != FeatureFlagConstants.FEATURE_FLAG_CONTENT_TYPE
+            ):
                 raise CLIErrors.ResourceNotFoundError(
-                    "The feature flag {} does not exist.".format(feature))
+                    "The feature flag {} does not exist.".format(feature)
+                )
 
             # we make sure that value retrieved is a valid json and only has the fields supported by backend.
             # if it's invalid, we catch appropriate exception that contains
@@ -1061,42 +1151,57 @@ def __clear_filter(azconfig_client,
 
             # These fields will never be missing because we validate that
             # in map_keyvalue_to_featureflagvalue
-            feature_filters = feature_flag_value.conditions[FeatureFlagConstants.CLIENT_FILTERS]
+            feature_filters = feature_flag_value.conditions[
+                FeatureFlagConstants.CLIENT_FILTERS
+            ]
 
             # create a deep copy of the filters to display to the user
             # after deletion
             display_filters = []
             if feature_filters:
-                confirmation_message = "Are you sure you want to delete all filters for feature '{0}'?\n".format(feature)
+                confirmation_message = "Are you sure you want to delete all filters for feature '{0}'?\n".format(
+                    feature
+                )
                 user_confirmation(confirmation_message, yes)
 
                 display_filters = copy.deepcopy(feature_filters)
                 # clearing feature_filters list for python 2.7 compatibility
                 del feature_filters[:]
 
-                __update_existing_key_value(azconfig_client=azconfig_client,
-                                            retrieved_kv=retrieved_kv,
-                                            updated_value=json.dumps(feature_flag_value,
-                                                                     default=lambda o: o.__dict__,
-                                                                     ensure_ascii=False))
+                __update_existing_key_value(
+                    azconfig_client=azconfig_client,
+                    retrieved_kv=retrieved_kv,
+                    updated_value=json.dumps(
+                        feature_flag_value,
+                        default=lambda o: o.__dict__,
+                        ensure_ascii=False,
+                    ),
+                )
 
             return display_filters
 
         except HttpResponseError as exception:
             if exception.status_code == StatusCodes.PRECONDITION_FAILED:
-                logger.debug('Retrying feature enable operation %s times with exception: concurrent setting operations', i + 1)
+                logger.debug(
+                    "Retrying feature enable operation %s times with exception: concurrent setting operations",
+                    i + 1,
+                )
                 time.sleep(retry_interval)
             else:
                 raise CLIErrors.AzureResponseError(str(exception))
         except Exception as exception:
             raise CLIError(str(exception))
     raise CLIError(
-        "Failed to delete filters for the feature flag '{}' due to a conflicting operation.".format(feature))
+        "Failed to delete filters for the feature flag '{}' due to a conflicting operation.".format(
+            feature
+        )
+    )
 
 
 def __update_existing_key_value(azconfig_client,
                                 retrieved_kv,
-                                updated_value):
+                                updated_value,
+                                correlation_request_id=None):
     '''
         To update the value of a pre-existing KeyValue
 
@@ -1118,7 +1223,7 @@ def __update_existing_key_value(azconfig_client,
                                   last_modified=retrieved_kv.last_modified)
 
     try:
-        new_kv = azconfig_client.set_configuration_setting(set_kv, match_condition=MatchConditions.IfNotModified)
+        new_kv = azconfig_client.set_configuration_setting(set_kv, match_condition=MatchConditions.IfNotModified, headers={HttpHeaders.CORRELATION_REQUEST_ID: correlation_request_id})
         return convert_configurationsetting_to_keyvalue(new_kv)
     except ResourceReadOnlyError:
         raise CLIError("Failed to update read only feature flag. Unlock the feature flag before updating it.")
@@ -1127,7 +1232,8 @@ def __update_existing_key_value(azconfig_client,
 
 def __list_all_keyvalues(azconfig_client,
                          key_filter,
-                         label=None):
+                         label=None,
+                         correlation_request_id=None):
     '''
         To get all keys by name or pattern
 
@@ -1151,7 +1257,7 @@ def __list_all_keyvalues(azconfig_client,
     label = prep_label_filter_for_url_encoding(label)
 
     try:
-        configsetting_iterable = azconfig_client.list_configuration_settings(key_filter=key_filter, label_filter=label)
+        configsetting_iterable = azconfig_client.list_configuration_settings(key_filter=key_filter, label_filter=label, headers={HttpHeaders.CORRELATION_REQUEST_ID: correlation_request_id})
     except HttpResponseError as exception:
         raise CLIErrors.AzureResponseError('Failed to read feature flag(s) that match the specified feature and label. ' + str(exception))
 
