@@ -312,12 +312,7 @@ class VolumeCreate(_VolumeCreate):
         args_schema.usage_threshold._default = 100
         args_schema.usage_threshold._fmt = AAZIntArgFormat(
             maximum=2400,
-            minimum=100
-        )
-
-        args_schema.coolness_period._fmt = AAZIntArgFormat(
-            maximum=183,
-            minimum=2,
+            minimum=50
         )
 
         # The API does only support setting Basic and Standard
@@ -441,12 +436,7 @@ class VolumeUpdate(_VolumeUpdate):
         )
         args_schema.usage_threshold._fmt = AAZIntArgFormat(
             maximum=2400,
-            minimum=100,
-        )
-
-        args_schema.coolness_period._fmt = AAZIntArgFormat(
-            maximum=183,
-            minimum=2,
+            minimum=50,
         )
 
         return args_schema
