@@ -111,6 +111,9 @@ def load_arguments(self, _):
     stacks_excluded_principals = CLIArgumentType(options_list=['--deny-settings-excluded-principals', '--ep'], help='List of AAD principal IDs excluded from the lock. Up to 5 principals are permitted.')
     stacks_excluded_actions = CLIArgumentType(options_list=['--deny-settings-excluded-actions', '--ea'], help="List of role-based management operations that are excluded from the denySettings. Up to 200 actions are permitted.")
     stacks_apply_to_child_scopes = CLIArgumentType(options_list=['--deny-settings-apply-to-child-scopes', '--cs'], help='DenySettings will be applied to child scopes.')
+    stacks_bypass_stack_out_of_sync_error_type = CLIArgumentType(
+        arg_type=get_three_state_flag(), options_list=['--bypass-stack-out-of-sync-error', '--bse'],
+        help='Flag to bypass service errors that indicate the stack resource list is not correctly synchronized.')
 
     bicep_file_type = CLIArgumentType(options_list=['--file', '-f'], completer=FilesCompleter(), type=file_type)
     bicep_force_type = CLIArgumentType(options_list=['--force'], action='store_true')
@@ -543,7 +546,9 @@ def load_arguments(self, _):
     with self.argument_context('group delete') as c:
         c.argument('resource_group_name', resource_group_name_type,
                    options_list=['--name', '-n', '--resource-group', '-g'], local_context_attribute=None)
-        c.argument('force_deletion_types', options_list=['--force-deletion-types', '-f'], arg_type=get_enum_type(['Microsoft.Compute/virtualMachines', 'Microsoft.Compute/virtualMachineScaleSets']), min_api='2021-04-01', help='The resource types you want to force delete.')
+        c.argument('force_deletion_types', options_list=['--force-deletion-types', '-f'], min_api='2021-04-01',
+                   arg_type=get_enum_type(['Microsoft.Compute/virtualMachines', 'Microsoft.Compute/virtualMachineScaleSets', 'Microsoft.Databricks/workspaces']),
+                   help='The resource types you want to force delete.')
 
     with self.argument_context('tag') as c:
         c.argument('tag_name', tag_name_type)
@@ -690,26 +695,12 @@ def load_arguments(self, _):
             c.argument('id', arg_type=stacks_stack_type)
             c.argument('subscription', arg_type=subscription_type)
 
-    def add_deprecated_stack_delete_flags(ctx):
-        ctx.argument(
-            'delete_resources', arg_type=get_three_state_flag(), options_list=['--delete-resources'],
-            help='Flag to indicate delete rather than detach for the resources.',
-            deprecate_info=ctx.deprecate(target='--delete-resources', redirect='--action-on-unmanage deleteResources'))
-        ctx.argument(
-            'delete_resource_groups', arg_type=get_three_state_flag(), options_list=['--delete-resource-groups'],
-            help='Flag to indicate delete rather than detach for the resource groups.',
-            deprecate_info=ctx.deprecate(target='--delete-resource-groups', redirect='--action-on-unmanage deleteAll'))
-        ctx.argument(
-            'delete_all', arg_type=get_three_state_flag(), options_list=['--delete-all'],
-            help='Flag to indicate delete rather than detach for the resources and resource groups.',
-            deprecate_info=ctx.deprecate(target='--delete-all', redirect='--action-on-unmanage deleteAll'))
-
     with self.argument_context('stack mg delete') as c:
         c.argument('name', options_list=['--name', '-n'], arg_type=stacks_stack_name_type)
         c.argument('id', arg_type=stacks_stack_type)
         c.argument('subscription', arg_type=subscription_type)
-        add_deprecated_stack_delete_flags(c)
         c.argument('action_on_unmanage', arg_type=stacks_action_on_unmanage_type)
+        c.argument('bypass_stack_out_of_sync_error', arg_type=stacks_bypass_stack_out_of_sync_error_type)
         c.argument('yes', help='Do not prompt for confirmation')
 
     with self.argument_context('stack mg list') as c:
@@ -725,12 +716,12 @@ def load_arguments(self, _):
         c.argument('name', options_list=['--name', '-n'], arg_type=stacks_stack_name_type)
         c.argument('id', arg_type=stacks_stack_type)
         c.argument('subscription', arg_type=subscription_type)
-        add_deprecated_stack_delete_flags(c)
         c.argument('action_on_unmanage', arg_type=stacks_action_on_unmanage_type)
+        c.argument('bypass_stack_out_of_sync_error', arg_type=stacks_bypass_stack_out_of_sync_error_type)
         c.argument('yes', help='Do not prompt for confirmation')
 
     for scope in ['group', 'sub', 'mg']:
-        for action in ['create']:  # 'validate' will be added in a future release
+        for action in ['create', 'validate']:
             with self.argument_context(f'stack {scope} {action}') as c:
                 c.argument('name', arg_type=stacks_name_type)
 
@@ -751,12 +742,12 @@ def load_arguments(self, _):
                 c.argument('parameters', arg_type=deployment_parameters_type, help='Parameters may be supplied from a file using the `@{path}` syntax, a JSON string, or as <KEY=VALUE> pairs. Parameters are evaluated in order, so when a value is assigned twice, the latter value will be used. It is recommended that you supply your parameters file first, and then override selectively using KEY=VALUE syntax.')
                 c.argument('description', arg_type=stacks_description_type)
                 c.argument('subscription', arg_type=subscription_type)
-                add_deprecated_stack_delete_flags(c)
                 c.argument('action_on_unmanage', arg_type=stacks_action_on_unmanage_type)
                 c.argument('deny_settings_mode', arg_type=stacks_deny_settings_mode)
                 c.argument('deny_settings_excluded_principals', arg_type=stacks_excluded_principals)
                 c.argument('deny_settings_excluded_actions', arg_type=stacks_excluded_actions)
                 c.argument('deny_settings_apply_to_child_scopes', arg_type=stacks_apply_to_child_scopes)
+                c.argument('bypass_stack_out_of_sync_error', arg_type=stacks_bypass_stack_out_of_sync_error_type)
                 c.argument('tags', tags_type)
 
                 if action == 'create':
@@ -778,8 +769,8 @@ def load_arguments(self, _):
         c.argument('resource_group', arg_type=resource_group_name_type, help='The resource group where the deployment stack exists')
         c.argument('id', arg_type=stacks_stack_type)
         c.argument('subscription', arg_type=subscription_type)
-        add_deprecated_stack_delete_flags(c)
         c.argument('action_on_unmanage', arg_type=stacks_action_on_unmanage_type)
+        c.argument('bypass_stack_out_of_sync_error', arg_type=stacks_bypass_stack_out_of_sync_error_type)
         c.argument('yes', help='Do not prompt for confirmation')
 
     with self.argument_context('bicep build') as c:
