@@ -217,6 +217,47 @@ for source in SOURCE_RESOURCES:
         # target resource params
         target_params = get_target_resource_params(target)
 
+        # special target resource to pass linter check with no auth params
+        if target == RESOURCE.ContainerApp:
+            helps['{source} connection create {target}'.format(source=source.value, target=target.value)] = """
+            type: command
+            short-summary: Create a containerapp-to-containerapp connection.
+            examples:
+                - name: Create a connection between containerapp and containerapp interactively
+                  text: |-
+                        az {source} connection create {target}
+                - name: Create a connection between {source_display_name} and {target} with resource name
+                  text: |-
+                        az {source} connection create {target} {source_params} {target_params}
+                - name: Create a connection between {source_display_name} and {target} with resource id
+                  text: |-
+                        az {source} connection create {target} --source-id {source_id} --target-id {target_id}
+            """.format(
+                source=source.value,
+                target=target.value,
+                source_id=source_id,
+                target_id=target_id,
+                source_params=source_params,
+                target_params=target_params,
+                source_display_name=source_display_name)
+
+            helps['{source} connection update {target}'.format(source=source.value, target=target.value)] = """
+            type: command
+            short-summary: Update a containerapp-to-containerapp connection.
+            examples:
+                - name: Update the client type of a connection with resource name
+                  text: |-
+                        az {source} connection update {target} {source_params} --connection MyConnection --client-type dotnet
+                - name: Update the client type of a connection with resource id
+                  text: |-
+                        az {source} connection update {target} --id {connection_id} --client-type dotnet
+            """.format(
+                source=source.value,
+                target=target.value,
+                source_params=source_params,
+                connection_id=connection_id)
+            continue
+
         # auth info params
         auth_types = SUPPORTED_AUTH_TYPE.get(source).get(target)
         if auth_types[0] == AUTH_TYPE.WorkloadIdentity:
@@ -224,6 +265,8 @@ for source in SOURCE_RESOURCES:
                 auth_params = '--enable-csi'
             else:
                 auth_params = get_auth_info_params(AUTH_TYPE.SecretAuto)
+        elif auth_types[0] == AUTH_TYPE.Null:
+            auth_params = ''
         else:
             auth_params = get_auth_info_params(auth_types[0])
 
@@ -310,7 +353,6 @@ for source in SOURCE_RESOURCES:
                 object-id      : Optional. Object id of the service principal (Enterprise Application).
                 secret         : Required. Secret of the service principal.
         ''' if AUTH_TYPE.ServicePrincipalSecret in auth_types else ''
-
         # create with `--new` examples
         provision_example = '''
             - name: Create a new {target} and connect {source_display_name} to it interactively
@@ -463,7 +505,6 @@ for source in SOURCE_RESOURCES:
                registry_params=registry_params,
                source_display_name=source_display_name)
 
-
 source = RESOURCE.Local
 connection_id = (
     '/subscriptions/{subscriptionId}/resourcegroups/{resourceGroupName}/'
