@@ -308,7 +308,7 @@ def add_extension(cmd=None, source=None, extension_name=None, index_url=None, ye
                   version=None, cli_ctx=None, upgrade=None, allow_preview=None):
     if allow_preview is None:
         logger.warning("Default enabled including preview versions for extension installation now. "
-                       "Disabled in May 2024. "
+                       "Disabled in future release. "
                        "Use '--allow-preview true' to enable it specifically if needed. "
                        "Use '--allow-preview false' to install stable version only. ")
         allow_preview = True
@@ -407,7 +407,7 @@ def show_extension(extension_name):
 def update_extension(cmd=None, extension_name=None, index_url=None, pip_extra_index_urls=None, pip_proxy=None, allow_preview=None, cli_ctx=None, version=None, download_url=None, ext_sha256=None):
     if allow_preview is None:
         logger.warning("Default enabled including preview versions for extension installation now. "
-                       "Disabled in May 2024. "
+                       "Disabled in future release. "
                        "Use '--allow-preview true' to enable it specifically if needed. "
                        "Use '--allow-preview false' to install stable version only. ")
         allow_preview = True
